@@ -47,26 +47,9 @@ STATIC_FILES = {
     '/jsCalendar': '/var/www/jsCalendar',
     '/ckeditor': '/var/www/ckeditor',
     '/mediaelement': '/var/www/mediaelement',
-    '/ckeditor': '/var/www/ckeditor',
     '/robots.txt': '/var/www/robots.txt',
     '/favicon.ico': '/var/www/favicon.ico',
 }
 
 CONFIG_FILENAME = 'invenio.conf'
 LOCAL_CONFIG_FILENAME = 'invenio-local.conf'
-
-# Print a warning after xx seconds when processing a request
-REQUEST_TIMEOUT = 0
-
-# Spawns a server that will accept connections to be able to
-# run arbitrary python code on the work
-USE_CONSOLE = False
-
-
-try:
-    import config_local
-    for setting in dir(config_local):
-        if setting == setting.upper():
-            globals()[setting] = getattr(config_local, setting)
-except ImportError:
-    pass
